from PyQt6.QtWidgets import (QMainWindow, QWidget, QVBoxLayout, QHBoxLayout,
                           QPushButton, QLabel, QFileDialog, QTabWidget,
                           QLineEdit, QMessageBox, QProgressBar, QListWidget)
from PyQt6.QtCore import Qt
from PyQt6.QtGui import QIcon
from core.converter import PDFConverter
from core.merger import PDFMerger
from core.splitter import PDFSplitter
from core.compressor import PDFCompressor
import os

class MainWindow(QMainWindow):
    def __init__(self):
        super().__init__()
        self.setWindowTitle("PDF工具箱")
        self.setMinimumSize(800, 600)
        self.selected_files = []
        self.setup_ui()

    def setup_ui(self):
        # 创建中心部件
        central_widget = QWidget()
        self.setCentralWidget(central_widget)
        layout = QVBoxLayout(central_widget)

        # 创建选项卡
        tab_widget = QTabWidget()
        
        # 添加各功能选项卡
        tab_widget.addTab(self.create_converter_tab(), "格式转换")
        tab_widget.addTab(self.create_merger_tab(), "PDF合并")
        tab_widget.addTab(self.create_splitter_tab(), "PDF拆分")
        tab_widget.addTab(self.create_compressor_tab(), "PDF压缩")
        # 删除水印选项卡
        
        layout.addWidget(tab_widget)

    def create_converter_tab(self):
        widget = QWidget()
        layout = QVBoxLayout(widget)
        
        # 添加文件选择
        select_file_btn = QPushButton("选择PDF文件（可多选）")
        select_file_btn.clicked.connect(self.select_pdf_files)
        
        # 添加文件列表显示
        self.files_list_widget = QListWidget()
        
        # 添加输出目录选择
        output_dir_layout = QHBoxLayout()
        self.output_dir_label = QLabel("输出目录：未选择")
        select_output_dir_btn = QPushButton("选择输出目录")
        select_output_dir_btn.clicked.connect(self.select_output_directory)
        output_dir_layout.addWidget(self.output_dir_label)
        output_dir_layout.addWidget(select_output_dir_btn)
        
        # 添加进度条
        self.progress_bar = QProgressBar()
        self.progress_bar.setVisible(False)
        
        # 添加转换按钮
        convert_to_word = QPushButton("批量转换为Word")
        convert_to_word.clicked.connect(lambda: self.batch_convert_files("word"))
        
        convert_to_image = QPushButton("批量转换为图片")
        convert_to_image.clicked.connect(lambda: self.batch_convert_files("images"))
        
        convert_to_markdown = QPushButton("批量转换为Markdown")
        convert_to_markdown.clicked.connect(lambda: self.batch_convert_files("markdown"))
        
        convert_to_excel = QPushButton("批量转换为Excel")
        convert_to_excel.clicked.connect(lambda: self.batch_convert_files("excel"))
        
        layout.addWidget(select_file_btn)
        layout.addWidget(self.files_list_widget)
        layout.addLayout(output_dir_layout)
        layout.addWidget(self.progress_bar)
        layout.addWidget(convert_to_word)
        layout.addWidget(convert_to_image)
        layout.addWidget(convert_to_markdown)
        layout.addWidget(convert_to_excel)
        
        return widget

    def select_pdf_files(self):
        files, _ = QFileDialog.getOpenFileNames(
            self,
            "选择PDF文件",
            "",
            "PDF文件 (*.pdf)"
        )
        if files:
            self.selected_files = files
            self.files_list_widget.clear()
            for file in files:
                self.files_list_widget.addItem(os.path.basename(file))

    def select_output_directory(self):
        output_dir = QFileDialog.getExistingDirectory(
            self,
            "选择输出目录"
        )
        if output_dir:
            self.output_directory = output_dir
            self.output_dir_label.setText(f"输出目录：{output_dir}")

    def batch_convert_files(self, convert_type):
        if not hasattr(self, 'selected_files') or not self.selected_files:
            QMessageBox.warning(self, "警告", "请先选择PDF文件！")
            return
            
        if not hasattr(self, 'output_directory'):
            QMessageBox.warning(self, "警告", "请选择输出目录！")
            return
            
        try:
            self.progress_bar.setVisible(True)
            self.progress_bar.setValue(0)
            
            # 计算总文件数用于进度显示
            total_files = len(self.selected_files)
            
            # 批量转换文件
            PDFConverter.batch_convert(self.selected_files, self.output_directory, convert_type)
            
            self.progress_bar.setValue(100)
            QMessageBox.information(self, "成功", "批量转换完成！")
            
        except Exception as e:
            QMessageBox.critical(self, "错误", f"转换失败：{str(e)}")
        finally:
            self.progress_bar.setVisible(False)

    def create_merger_tab(self):
        widget = QWidget()
        layout = QVBoxLayout(widget)
        
        # 添加文件选择按钮和文件列表显示
        select_files = QPushButton("选择PDF文件")
        select_files.clicked.connect(self.select_multiple_pdfs)
        
        self.files_label = QLabel("未选择文件")
        
        # 添加进度条
        self.merger_progress = QProgressBar()
        self.merger_progress.setVisible(False)
        
        merge_button = QPushButton("合并PDF")
        merge_button.clicked.connect(self.merge_pdfs)
        
        layout.addWidget(select_files)
        layout.addWidget(self.files_label)
        layout.addWidget(self.merger_progress)
        layout.addWidget(merge_button)
        
        return widget
    
    def select_multiple_pdfs(self):
        files, _ = QFileDialog.getOpenFileNames(
            self,
            "选择多个PDF文件",
            "",
            "PDF文件 (*.pdf)"
        )
        if files:
            self.selected_files = files
            self.files_label.setText(f"已选择 {len(files)} 个文件")
    
    def merge_pdfs(self):
        if len(self.selected_files) < 2:
            QMessageBox.warning(self, "警告", "请至少选择两个PDF文件！")
            return
            
        try:
            output_file, _ = QFileDialog.getSaveFileName(
                self,
                "保存合并后的PDF",
                "",
                "PDF文件 (*.pdf)"
            )
            
            if output_file:
                self.merger_progress.setVisible(True)
                self.merger_progress.setValue(0)
                
                PDFMerger.merge_pdfs(self.selected_files, output_file)
                
                self.merger_progress.setValue(100)
                QMessageBox.information(self, "成功", "PDF合并完成！")
                
        except Exception as e:
            QMessageBox.critical(self, "错误", f"合并失败：{str(e)}")
        finally:
            self.merger_progress.setVisible(False)

    def create_splitter_tab(self):
        widget = QWidget()
        layout = QVBoxLayout(widget)
        
        # 添加文件选择和拆分按钮
        select_file = QPushButton("选择PDF文件")
        select_file.clicked.connect(self.select_pdf_for_split)
        
        self.split_file_label = QLabel("未选择文件")
        
        # 添加进度条
        self.split_progress = QProgressBar()
        self.split_progress.setVisible(False)
        
        split_button = QPushButton("拆分PDF")
        split_button.clicked.connect(self.split_pdf)
        
        layout.addWidget(select_file)
        layout.addWidget(self.split_file_label)
        layout.addWidget(self.split_progress)
        layout.addWidget(split_button)
        
        return widget

    def select_pdf_for_split(self):
        file_name, _ = QFileDialog.getOpenFileName(
            self,
            "选择要拆分的PDF文件",
            "",
            "PDF文件 (*.pdf)"
        )
        if file_name:
            self.split_file = file_name
            self.split_file_label.setText(f"已选择: {os.path.basename(file_name)}")

    def split_pdf(self):
        if not hasattr(self, 'split_file'):
            QMessageBox.warning(self, "警告", "请先选择PDF文件！")
            return
            
        try:
            output_dir = QFileDialog.getExistingDirectory(
                self,
                "选择保存目录"
            )
            
            if output_dir:
                self.split_progress.setVisible(True)
                self.split_progress.setValue(0)
                
                PDFSplitter.split_pdf(self.split_file, output_dir)
                
                self.split_progress.setValue(100)
                QMessageBox.information(self, "成功", "PDF拆分完成！")
                
        except Exception as e:
            QMessageBox.critical(self, "错误", f"拆分失败：{str(e)}")
        finally:
            self.split_progress.setVisible(False)

    def create_compressor_tab(self):
        widget = QWidget()
        layout = QVBoxLayout(widget)
        
        # 添加文件选择和压缩按钮
        select_file = QPushButton("选择PDF文件")
        select_file.clicked.connect(self.select_pdf_for_compress)
        
        self.compress_file_label = QLabel("未选择文件")
        
        # 添加进度条
        self.compress_progress = QProgressBar()
        self.compress_progress.setVisible(False)
        
        compress_button = QPushButton("压缩PDF")
        compress_button.clicked.connect(self.compress_pdf)
        
        layout.addWidget(select_file)
        layout.addWidget(self.compress_file_label)
        layout.addWidget(self.compress_progress)
        layout.addWidget(compress_button)
        
        return widget
    
    def select_pdf_for_compress(self):
        file_name, _ = QFileDialog.getOpenFileName(
            self,
            "选择要压缩的PDF文件",
            "",
            "PDF文件 (*.pdf)"
        )
        if file_name:
            self.compress_file = file_name
            self.compress_file_label.setText(f"已选择: {os.path.basename(file_name)}")
    
    def compress_pdf(self):
        if not hasattr(self, 'compress_file'):
            QMessageBox.warning(self, "警告", "请先选择PDF文件！")
            return
            
        try:
            output_file, _ = QFileDialog.getSaveFileName(
                self,
                "保存压缩后的PDF",
                "",
                "PDF文件 (*.pdf)"
            )
            
            if output_file:
                self.compress_progress.setVisible(True)
                self.compress_progress.setValue(0)
                
                PDFCompressor.compress_pdf(self.compress_file, output_file)
                
                self.compress_progress.setValue(100)
                QMessageBox.information(self, "成功", "PDF压缩完成！")
                
        except Exception as e:
            QMessageBox.critical(self, "错误", f"压缩失败：{str(e)}")
        finally:
            self.compress_progress.setVisible(False)

    # 删除以下水印相关的方法:
    # - create_watermark_tab
    # - select_watermark_color
    # - select_pdf_for_watermark
    # - add_watermark